# dms-collector changelog

## version 2.0.3

* Read and connect timeouts options.

## version 2.0.2

* DMS table file cache; table headers and their descriptions can be stored in a file when they are retrieved from DMS. This may reduce one interaction when retrieving DMS metrics. 
